@@ -196,6 +196,49 @@ foreach my $p (1..(25 * $factor)) {
 }
 sleep $wait;
 
+print_it($F,'Arc test');
+
+foreach my $p (1..(30 * $factor)) {
+   $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
+    $F->arc({'x' => rand($XX),'y' => rand($YY),'radius' => rand($YY),'start_degrees' => rand(360),'end_degrees' => rand(360)});
+}
+sleep $wait;
+print_it($F,'PolyArc test');
+
+foreach my $p (1..(30 * $factor)) {
+   $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
+    $F->poly_arc({'x' => rand($XX),'y' => rand($YY),'radius' => rand($YY),'start_degrees' => rand(360),'end_degrees' => rand(360)});
+}
+sleep $wait;
+print_it($F,'PieArc test');
+
+foreach my $p (1..(30 * $factor)) {
+   $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
+    $F->filled_pie({'x' => rand($XX),'y' => rand($YY),'radius' => rand($YY),'start_degrees' => rand(360),'end_degrees' => rand(360)});
+}
+sleep $wait;
+print_it($F,'Gradient PieArc test');
+
+foreach my $p (1..(30 * $factor)) {
+   $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
+    $F->filled_pie({'x' => rand($XX),'y' => rand($YY),'radius' => rand($YY),'start_degrees' => rand(360),'end_degrees' => rand(360),
+                   'gradient' => {
+                       'start' => {
+                           'red'   => rand(256),
+                           'green' => rand(256),
+                           'blue'  => rand(256)
+                       },
+                       'end' => {
+                           'red'   => rand(256),
+                           'green' => rand(256),
+                           'blue'  => rand(256)
+                       }
+                   }
+                   }
+    );
+}
+sleep $wait;
+
 print_it($F,'Polygon Test');
 foreach my $p (1..(25 * $factor)) {
     $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
@@ -217,7 +260,7 @@ foreach my $p (1..(20 * $factor)) {
                     'gradient' => {
                         'start' => {
                             'red'   => rand(256),
-                           'green' => rand(256),
+                            'green' => rand(256),
                             'blue'  => rand(256)
                         },
                         'end' => {
